@@ -1,14 +1,11 @@
+from argparse import ArgumentParser
 import numpy as np
-import scipy as sp
-import scipy.stats
 from ngboost.distns import Normal
 from ngboost.ngboost import NGBoost
-from ngboost.scores import MLE, CRPS
-from ngboost.learners import default_tree_learner, default_linear_learner
+from ngboost.learners import default_linear_learner
 from ngboost.evaluation import *
 from sklearn.metrics import r2_score
 from matplotlib import pyplot as plt
-from argparse import ArgumentParser
 
 
 if __name__ == "__main__":
